@@ -3,6 +3,7 @@ import pathlib
 import time
 import os
 import json
+import shutil
 import unittest
 
 
@@ -24,7 +25,6 @@ class TestCase(unittest.TestCase):
     def assert_attributes_equal(self, thing=None, attributes=None):
         self.assertEqual(sorted(dir(thing)), attributes)
 
-
 def logger(message, level="INFO"):
     print(f"[{level}] {message}")
 
@@ -75,4 +75,19 @@ def time_it(function, *args, description='run process', **kwargs):
     start_time = time.time()
     result = function(*args, **kwargs)
     log(f'Time taken to {description}::{time.time() - start_time:.1f} seconds')
-    return result
\ No newline at end of file
+    return result
+
+def remove_dist():
+    try:
+        shutil.rmtree('dist')
+    except FileNotFoundError:
+        'already removed'
+
+def get_commit_message():
+    return input("Enter commit message: ")
+
+def build_and_publish():
+    remove_dist()
+    os.system(f'git commit -am "{get_commit_message()}"')
+    os.system('python3 -m build')
+    os.system('python3 -m twine upload dist/*')
\ No newline at end of file
